@@ -304,10 +304,12 @@ read_pool( byte *buffer, size_t length, int level )
 static void
 add_randomness( const void *buffer, size_t length, int source )
 {
+    const byte *p = buffer;
+
     if( !is_initialized )
 	initialize();
     while( length-- ) {
-	rndpool[pool_writepos++] = *((byte*)buffer)++;
+	rndpool[pool_writepos++] = *p++;
 	if( pool_writepos >= POOLSIZE ) {
 	    if( source > 1 )
 		pool_filled = 1;
@@ -358,10 +360,12 @@ fast_random_poll()
 	add_randomness( &tv.tv_usec, sizeof(tv.tv_usec), 1 );
     }
   #else /* use times */
+    #ifndef HAVE_DOSISH_SYSTEM
     {	struct tms buf;
 	times( &buf );
 	add_randomness( &buf, sizeof buf, 1 );
     }
+    #endif
   #endif
   #ifdef HAVE_GETRUSAGE
     {	struct rusage buf;
