@@ -43,6 +43,7 @@ static int do_pubkey_enc( IOBUF out, int ctb, PKT_pubkey_enc *enc );
 static u32 calc_plaintext( PKT_plaintext *pt );
 static int do_plaintext( IOBUF out, int ctb, PKT_plaintext *pt );
 static int do_encrypted( IOBUF out, int ctb, PKT_encrypted *ed );
+static int do_encrypted_mdc( IOBUF out, int ctb, PKT_encrypted *ed );
 static int do_compressed( IOBUF out, int ctb, PKT_compressed *cd );
 static int do_signature( IOBUF out, int ctb, PKT_signature *sig );
 static int do_onepass_sig( IOBUF out, int ctb, PKT_onepass_sig *ops );
@@ -74,7 +75,8 @@ build_packet( IOBUF out, PACKET *pkt )
     switch( pkt->pkttype ) {
       case PKT_OLD_COMMENT: pkt->pkttype = PKT_COMMENT; break;
       case PKT_PLAINTEXT: new_ctb = pkt->pkt.plaintext->new_ctb; break;
-      case PKT_ENCRYPTED: new_ctb = pkt->pkt.encrypted->new_ctb; break;
+      case PKT_ENCRYPTED:
+      case PKT_ENCRYPTED_MDC: new_ctb = pkt->pkt.encrypted->new_ctb; break;
       case PKT_COMPRESSED:new_ctb = pkt->pkt.compressed->new_ctb; break;
       default: break;
     }
@@ -110,6 +112,9 @@ build_packet( IOBUF out, PACKET *pkt )
       case PKT_ENCRYPTED:
 	rc = do_encrypted( out, ctb, pkt->pkt.encrypted );
 	break;
+      case PKT_ENCRYPTED_MDC:
+	rc = do_encrypted_mdc( out, ctb, pkt->pkt.encrypted );
+	break;
       case PKT_COMPRESSED:
 	rc = do_compressed( out, ctb, pkt->pkt.compressed );
 	break;
@@ -166,13 +171,12 @@ calc_packet_length( PACKET *pkt )
 static void
 write_fake_data( IOBUF out, MPI a )
 {
-    byte *s;
-    u16 len;
-
     if( a ) {
-	s = (byte*)a;
-	len = (s[0] << 8) | s[1];
-	iobuf_write( out, s+2, len );
+	int i;
+	void *p;
+
+	p = mpi_get_opaque( a, &i );
+	iobuf_write( out, p, i );
     }
 }
 
@@ -509,6 +513,24 @@ do_encrypted( IOBUF out, int ctb, PKT_encrypted *ed )
     return rc;
 }
 
+static int
+do_encrypted_mdc( IOBUF out, int ctb, PKT_encrypted *ed )
+{
+    int rc = 0;
+    u32 n;
+
+    assert( ed->mdc_method );
+
+    n = ed->len ? (ed->len + 10) : 0;
+    write_header(out, ctb, n );
+    iobuf_put(out, 1 );  /* version */
+    iobuf_put(out, ed->mdc_method );
+
+    /* This is all. The caller has to write the real data */
+
+    return rc;
+}
+
 static int
 do_compressed( IOBUF out, int ctb, PKT_compressed *cd )
 {
@@ -561,6 +583,7 @@ find_subpkt( byte *buffer, sigsubpkttype_t reqtype,
 	    if( buflen < 2 )
 		break;
 	    n = (( n - 192 ) << 8) + *buffer + 192;
+	    buffer++;
 	    buflen--;
 	}
 	if( buflen < n )
@@ -732,15 +755,9 @@ do_signature( IOBUF out, int ctb, PKT_signature *sig )
     }
     iobuf_put(a, sig->digest_start[0] );
     iobuf_put(a, sig->digest_start[1] );
-    n = sig->pubkey_algo? pubkey_get_nsig( sig->pubkey_algo ) : 0;
-    if( !n ) {	/* the MDC data */
-	fputs("The MDC: ", stderr);
-	mpi_print(stderr, sig->data[0], 0 );
-	fputs("  ", stderr);
-	mpi_print(stderr, sig->data[0], 1 );
-	putc('\n', stderr);
-	mpi_write( a, sig->data[0] );
-    }
+    n = pubkey_get_nsig( sig->pubkey_algo );
+    if( !n )
+	write_fake_data( a, sig->data[0] );
     for(i=0; i < n; i++ )
 	mpi_write(a, sig->data[i] );
 
