@@ -52,6 +52,7 @@ enum cmd_and_opt_values { aNull = 0,
     aSym	  = 'c',
     aDecrypt	  = 'd',
     aEncr	  = 'e',
+    oInteractive  = 'i',
     oKOption	  = 'k',
     oDryRun	  = 'n',
     oOutput	  = 'o',
@@ -155,6 +156,7 @@ enum cmd_and_opt_values { aNull = 0,
     oKeyServer,
     oEncryptTo,
     oNoEncryptTo,
+    oLoggerFD,
 aTest };
 
 
@@ -223,6 +225,7 @@ static ARGPARSE_OPTS opts[] = {
     { oForceV3Sigs, "force-v3-sigs", 0, N_("force v3 signatures") },
     { oForceMDC, "force-mdc", 0, N_("always use a MDC for encryption") },
     { oDryRun, "dry-run",   0, N_("do not make any changes") },
+  /*{ oInteractive, "interactive", 0, N_("prompt before overwriting") }, */
     { oBatch, "batch",     0, N_("batch mode: never ask")},
     { oAnswerYes, "yes",       0, N_("assume yes on most questions")},
     { oAnswerNo,  "no",        0, N_("assume no on most questions")},
@@ -293,6 +296,7 @@ static ARGPARSE_OPTS opts[] = {
     { oNotDashEscaped, "not-dash-escaped", 0, "@" },
     { oEscapeFrom, "escape-from-lines", 0, "@" },
     { oLockOnce, "lock-once", 0, "@" },
+    { oLoggerFD, "logger-fd",1, "@" },
 {0} };
 
 
@@ -637,6 +641,7 @@ main( int argc, char **argv )
 	  case oOutput: opt.outfile = pargs.r.ret_str; break;
 	  case oQuiet: opt.quiet = 1; break;
 	  case oDryRun: opt.dry_run = 1; break;
+	  case oInteractive: opt.interactive = 1; break;
 	  case oVerbose: g10_opt_verbose++;
 		    opt.verbose++; opt.list_sigs=1; break;
 	  case oKOption: set_cmd( &cmd, aKMode ); break;
@@ -648,6 +653,7 @@ main( int argc, char **argv )
 	  case oDebug: opt.debug |= pargs.r.ret_ulong; break;
 	  case oDebugAll: opt.debug = ~0; break;
 	  case oStatusFD: set_status_fd( pargs.r.ret_int ); break;
+	  case oLoggerFD: log_set_logfile( NULL, pargs.r.ret_int ); break;
 	  case oFingerprint: opt.fingerprint++; break;
 	  case oSecretKeyring: append_to_strlist( &sec_nrings, pargs.r.ret_str); break;
 	  case oOptions:
@@ -843,11 +849,11 @@ main( int argc, char **argv )
     if( cmd != aDeArmor && cmd != aEnArmor
 	&& !(cmd == aKMode && argc == 2 ) ) {
 
-	if( !sec_nrings || default_keyring )  /* add default secret rings */
+	if( !sec_nrings && default_keyring )  /* add default secret rings */
 	    add_keyblock_resource("secring.gpg", 0, 1);
 	for(sl = sec_nrings; sl; sl = sl->next )
 	    add_keyblock_resource( sl->d, 0, 1 );
-	if( !nrings || default_keyring )  /* add default ring */
+	if( !nrings && default_keyring )  /* add default ring */
 	    add_keyblock_resource("pubring.gpg", 0, 0);
 	for(sl = nrings; sl; sl = sl->next )
 	    add_keyblock_resource( sl->d, 0, 0 );
