@@ -51,6 +51,9 @@ struct kbnode_struct {
     ulong recno;  /* used while updating the trustdb */
 };
 
+#define is_deleted_kbnode(a)  ((a)->private_flag & 1)
+#define is_cloned_kbnode(a)   ((a)->private_flag & 2)
+
 
 enum resource_type {
     rt_UNKNOWN = 0,
@@ -180,6 +183,8 @@ void release_kbnode( KBNODE n );
 void delete_kbnode( KBNODE node );
 void add_kbnode( KBNODE root, KBNODE node );
 void insert_kbnode( KBNODE root, KBNODE node, int pkttype );
+void move_kbnode( KBNODE *root, KBNODE node, KBNODE where );
+void remove_kbnode( KBNODE *root, KBNODE node );
 KBNODE find_prev_kbnode( KBNODE root, KBNODE node, int pkttype );
 KBNODE find_next_kbnode( KBNODE node, int pkttype );
 KBNODE find_kbnode( KBNODE node, int pkttype );
