@@ -113,6 +113,7 @@ KBNODE make_mpi_comment_node( const char *s, MPI a );
 /*-- import.c --*/
 int import_keys( const char *filename, int fast );
 int import_keys_stream( IOBUF inp, int fast );
+int collapse_uids( KBNODE *keyblock );
 
 /*-- export.c --*/
 int export_pubkeys( STRLIST users, int onlyrfc );
@@ -137,8 +138,8 @@ int verify_signatures( int nfiles, char **files );
 int decrypt_message( const char *filename );
 
 /*-- plaintext.c --*/
-int hash_datafiles( MD_HANDLE md, STRLIST files, const char *sigfilename,
-		    int textmode );
+int hash_datafiles( MD_HANDLE md, MD_HANDLE md2,
+		    STRLIST files, const char *sigfilename, int textmode );
 
 /*-- signal.c --*/
 void init_signals(void);
