@@ -1,4 +1,4 @@
-/* mainproc.c - handle packets
+/* maPPPPinproc.c - handle packets
  *	Copyright (C) 1998, 1999 Free Software Foundation, Inc.
  *
  * This file is part of GnuPG.
@@ -44,7 +44,7 @@
  */
 typedef struct mainproc_context *CTX;
 struct mainproc_context {
-    struct mainproc_context *anchor;
+    struct mainproc_context *anchor;  /* may be useful in the future */
     PKT_public_key *last_pubkey;
     PKT_secret_key *last_seckey;
     PKT_user_id     *last_user_id;
@@ -60,7 +60,6 @@ struct mainproc_context {
     IOBUF iobuf;    /* used to get the filename etc. */
     int trustletter; /* temp usage in list_node */
     ulong local_id;    /* ditto */
-    int is_encrypted;  /* used to check the MDC */
 };
 
 
@@ -229,7 +228,6 @@ proc_encrypted( CTX c, PACKET *pkt )
     int result = 0;
 
     /*log_debug("dat: %sencrypted data\n", c->dek?"":"conventional ");*/
-    c->is_encrypted = 1;
     if( !c->dek && !c->last_was_session_key ) {
 	/* assume this is old conventional encrypted data */
 	c->dek = passphrase_to_dek( NULL,
@@ -247,6 +245,12 @@ proc_encrypted( CTX c, PACKET *pkt )
 	write_status( STATUS_DECRYPTION_OKAY );
 	if( opt.verbose > 1 )
 	    log_info(_("decryption okay\n"));
+	if( pkt->pkt.encrypted->mdc_method )
+	    write_status( STATUS_GOODMDC );
+    }
+    else if( result == G10ERR_BAD_SIGN ) {
+	log_error(_("WARNING: encrypted message has been manipulated!\n"));
+	write_status( STATUS_BADMDC );
     }
     else {
 	write_status( STATUS_DECRYPTION_FAILED );
@@ -259,11 +263,12 @@ proc_encrypted( CTX c, PACKET *pkt )
 }
 
 
+
 static void
 proc_plaintext( CTX c, PACKET *pkt )
 {
     PKT_plaintext *pt = pkt->pkt.plaintext;
-    int any, clearsig, rc;
+    int any, clearsig, only_md5, rc;
     KBNODE n;
 
     if( pt->namelen == 8 && !memcmp( pt->name, "_CONSOLE", 8 ) )
@@ -278,13 +283,21 @@ proc_plaintext( CTX c, PACKET *pkt )
      * Should we assume that plaintext in mode 't' has always sigclass 1??
      * See: Russ Allbery's mail 1999-02-09
      */
-    any = clearsig = 0;
+    any = clearsig = only_md5 = 0;
     for(n=c->list; n; n = n->next ) {
 	if( n->pkt->pkttype == PKT_ONEPASS_SIG ) {
 	    if( n->pkt->pkt.onepass_sig->digest_algo ) {
 		md_enable( c->mfx.md, n->pkt->pkt.onepass_sig->digest_algo );
+		if( !any && n->pkt->pkt.onepass_sig->digest_algo
+						      == DIGEST_ALGO_MD5 )
+		    only_md5 = 1;
+		else
+		    only_md5 = 0;
 		any = 1;
 	    }
+	    if( n->pkt->pkt.onepass_sig->sig_class != 0x01 )
+		only_md5 = 0;
+
 	    /* Check whether this is a cleartext signature.  We assume that
 	     * we have one if the sig_class is 1 and the keyid is 0, that
 	     * are the faked packets produced by armor.c.  There is a
@@ -292,9 +305,6 @@ proc_plaintext( CTX c, PACKET *pkt )
 	     * to do it. (We could use a special packet type to indicate
 	     * this, but this may also be faked - it simply can't be verified
 	     * and is _no_ security issue)
-	     * Hmmm: There is one problem: The MDC also uses a keyid of 0
-	     * and a pubkey algo of 0 - the only difference is that the
-	     * sig_class will be 0.
 	     */
 	    if( n->pkt->pkt.onepass_sig->sig_class == 0x01
 		&& !n->pkt->pkt.onepass_sig->keyid[0]
@@ -307,6 +317,14 @@ proc_plaintext( CTX c, PACKET *pkt )
 	md_enable( c->mfx.md, DIGEST_ALGO_SHA1 );
 	md_enable( c->mfx.md, DIGEST_ALGO_MD5 );
     }
+    if( only_md5 ) {
+	/* This is a kludge to work around a bug in pgp2.  It does only
+	 * catch those mails which are armored.  To catch the non-armored
+	 * pgp mails we could see whether there is the signature packet
+	 * in front of the plaintext.  If someone needs this, send me a patch.
+	 */
+	c->mfx.md2 = md_open( DIGEST_ALGO_MD5, 0);
+    }
   #if 0
     #warning md_start_debug is enabled
     md_start_debug( c->mfx.md, "verify" );
@@ -356,16 +374,6 @@ proc_compressed( CTX c, PACKET *pkt )
     c->last_was_session_key = 0;
 }
 
-static int
-is_encrypted( CTX c )
-{
-    for( ; c; c = c->anchor ) {
-	if( c->is_encrypted )
-	    return 1;
-    }
-    return 0;
-}
-
 /****************
  * check the signature
  * Returns: 0 = valid signature or an error code
@@ -374,7 +382,7 @@ static int
 do_check_sig( CTX c, KBNODE node, int *is_selfsig )
 {
     PKT_signature *sig;
-    MD_HANDLE md;
+    MD_HANDLE md = NULL, md2 = NULL;
     int algo, rc;
 
     assert( node->pkt->pkttype == PKT_SIGNATURE );
@@ -395,10 +403,16 @@ do_check_sig( CTX c, KBNODE node, int *is_selfsig )
     else if( sig->sig_class == 0x01 ) {
 	/* how do we know that we have to hash the (already hashed) text
 	 * in canonical mode ??? (calculating both modes???) */
-	if( c->mfx.md )
+	if( c->mfx.md ) {
 	    md = md_copy( c->mfx.md );
-	else /* detached signature */
+	    if( c->mfx.md2 )
+	       md2 = md_copy( c->mfx.md2 );
+	}
+	else { /* detached signature */
+	  log_debug("Do we really need this here?");
 	    md = md_open( 0, 0 ); /* signature_check() will enable the md*/
+	    md2 = md_open( 0, 0 );
+	}
     }
     else if( (sig->sig_class&~3) == 0x10
 	     || sig->sig_class == 0x18
@@ -416,13 +430,11 @@ do_check_sig( CTX c, KBNODE node, int *is_selfsig )
     }
     else
 	return G10ERR_SIG_CLASS;
-    if( sig->pubkey_algo )
-	rc = signature_check( sig, md );
-    else if( !is_encrypted( c ) )
-	rc = G10ERR_NOT_ENCRYPTED;
-    else
-	rc = mdc_kludge_check( sig, md );
+    rc = signature_check( sig, md );
+    if( rc == G10ERR_BAD_SIGN && md2 )
+	rc = signature_check( sig, md2 );
     md_close(md);
+    md_close(md2);
 
     return rc;
 }
@@ -771,7 +783,8 @@ do_proc_packets( CTX c, IOBUF a )
 	    switch( pkt->pkttype ) {
 	      case PKT_PUBKEY_ENC:  proc_pubkey_enc( c, pkt ); break;
 	      case PKT_SYMKEY_ENC:  proc_symkey_enc( c, pkt ); break;
-	      case PKT_ENCRYPTED:   proc_encrypted( c, pkt ); break;
+	      case PKT_ENCRYPTED:
+	      case PKT_ENCRYPTED_MDC: proc_encrypted( c, pkt ); break;
 	      case PKT_COMPRESSED:  proc_compressed( c, pkt ); break;
 	      default: newpkt = 0; break;
 	    }
@@ -784,6 +797,7 @@ do_proc_packets( CTX c, IOBUF a )
 	      case PKT_SYMKEY_ENC:
 	      case PKT_PUBKEY_ENC:
 	      case PKT_ENCRYPTED:
+	      case PKT_ENCRYPTED_MDC:
 		rc = G10ERR_UNEXPECTED;
 		goto leave;
 	      case PKT_SIGNATURE:   newpkt = add_signature( c, pkt ); break;
@@ -803,7 +817,8 @@ do_proc_packets( CTX c, IOBUF a )
 	      case PKT_SIGNATURE:   newpkt = add_signature( c, pkt ); break;
 	      case PKT_SYMKEY_ENC:  proc_symkey_enc( c, pkt ); break;
 	      case PKT_PUBKEY_ENC:  proc_pubkey_enc( c, pkt ); break;
-	      case PKT_ENCRYPTED:   proc_encrypted( c, pkt ); break;
+	      case PKT_ENCRYPTED:
+	      case PKT_ENCRYPTED_MDC: proc_encrypted( c, pkt ); break;
 	      case PKT_PLAINTEXT:   proc_plaintext( c, pkt ); break;
 	      case PKT_COMPRESSED:  proc_compressed( c, pkt ); break;
 	      case PKT_ONEPASS_SIG: newpkt = add_onepass_sig( c, pkt ); break;
@@ -826,7 +841,8 @@ do_proc_packets( CTX c, IOBUF a )
 	      case PKT_SIGNATURE:   newpkt = add_signature( c, pkt ); break;
 	      case PKT_PUBKEY_ENC:  proc_pubkey_enc( c, pkt ); break;
 	      case PKT_SYMKEY_ENC:  proc_symkey_enc( c, pkt ); break;
-	      case PKT_ENCRYPTED:   proc_encrypted( c, pkt ); break;
+	      case PKT_ENCRYPTED:
+	      case PKT_ENCRYPTED_MDC: proc_encrypted( c, pkt ); break;
 	      case PKT_PLAINTEXT:   proc_plaintext( c, pkt ); break;
 	      case PKT_COMPRESSED:  proc_compressed( c, pkt ); break;
 	      case PKT_ONEPASS_SIG: newpkt = add_onepass_sig( c, pkt ); break;
@@ -863,48 +879,29 @@ do_proc_packets( CTX c, IOBUF a )
 }
 
 
-
 static int
 check_sig_and_print( CTX c, KBNODE node )
 {
     PKT_signature *sig = node->pkt->pkt.signature;
     const char *astr, *tstr;
     int rc;
-    int mdc_hack = !sig->pubkey_algo;
 
-    if( opt.skip_verify && !mdc_hack ) {
+    if( opt.skip_verify ) {
 	log_info(_("signature verification suppressed\n"));
 	return 0;
     }
 
-    if( !mdc_hack ) {
-	tstr = asctimestamp(sig->timestamp);
-	astr = pubkey_algo_to_string( sig->pubkey_algo );
-	log_info(_("Signature made %.*s using %s key ID %08lX\n"),
+    tstr = asctimestamp(sig->timestamp);
+    astr = pubkey_algo_to_string( sig->pubkey_algo );
+    log_info(_("Signature made %.*s using %s key ID %08lX\n"),
 	    (int)strlen(tstr), tstr, astr? astr: "?", (ulong)sig->keyid[1] );
-    }
 
     rc = do_check_sig(c, node, NULL );
     if( rc == G10ERR_NO_PUBKEY && opt.keyserver_name ) {
 	if( !hkp_ask_import( sig->keyid ) )
 	    rc = do_check_sig(c, node, NULL );
     }
-    if( mdc_hack ) {
-	if( !rc ) {
-	    if( opt.verbose )
-		log_info(_("encrypted message is valid\n"));
-	    write_status( STATUS_GOODMDC );
-	}
-	else if( rc == G10ERR_BAD_SIGN ) {
-	    log_error(_("WARNING: encrypted message has been manipulated!\n"));
-	    write_status( STATUS_BADMDC );
-	}
-	else {
-	    write_status( STATUS_ERRMDC );
-	    log_error(_("Can't check MDC: %s\n"), g10_errstr(rc) );
-	}
-    }
-    else if( !rc || rc == G10ERR_BAD_SIGN ) {
+    if( !rc || rc == G10ERR_BAD_SIGN ) {
 	KBNODE un, keyblock;
 	char *us;
 	int count=0;
@@ -926,16 +923,16 @@ check_sig_and_print( CTX c, KBNODE node )
 			   : _("Good signature from \""));
 	    else
 		log_info(    _("                aka \""));
-	    print_string( stderr, un->pkt->pkt.user_id->name,
-				  un->pkt->pkt.user_id->len, '\"' );
-	    fputs("\"\n", stderr);
+	    print_string( log_stream(), un->pkt->pkt.user_id->name,
+					un->pkt->pkt.user_id->len, '\"' );
+	    fputs("\"\n", log_stream() );
 	    if( rc )
 		break; /* print only one id in this case */
 	}
 	if( !count ) {	/* just in case that we have no userid */
 	    log_info(rc? _("BAD signature from \"")
 		       : _("Good signature from \""));
-	    fputs("[?]\"\n", stderr );
+	    fputs("[?]\"\n", log_stream() );
 	}
 	release_kbnode( keyblock );
 
@@ -946,13 +943,16 @@ check_sig_and_print( CTX c, KBNODE node )
 
 	    if( !get_pubkey( pk, sig->keyid ) ) {
 		byte array[MAX_FINGERPRINT_LEN], *p;
-		char buf[MAX_FINGERPRINT_LEN*2+1];
+		char buf[MAX_FINGERPRINT_LEN*2+61];
 		size_t i, n;
 
 		fingerprint_from_pk( pk, array, &n );
 		p = array;
 		for(i=0; i < n ; i++, p++ )
 		    sprintf(buf+2*i, "%02X", *p );
+		sprintf(buf+strlen(buf), " %s %lu",
+					 strtimestamp( sig->timestamp ),
+					 (ulong)sig->timestamp );
 		write_status_text( STATUS_VALIDSIG, buf );
 	    }
 	    free_public_key( pk );
@@ -967,9 +967,10 @@ check_sig_and_print( CTX c, KBNODE node )
     }
     else {
 	char buf[50];
-	sprintf(buf, "%08lX%08lX %d",
+	sprintf(buf, "%08lX%08lX %d %d %02x %lu %d",
 		     (ulong)sig->keyid[0], (ulong)sig->keyid[1],
-		     sig->pubkey_algo );
+		     sig->pubkey_algo, sig->digest_algo,
+		     sig->sig_class, (ulong)sig->timestamp, rc );
 	write_status_text( STATUS_ERRSIG, buf );
 	log_error(_("Can't check signature: %s\n"), g10_errstr(rc) );
     }
@@ -1006,13 +1007,15 @@ proc_tree( CTX c, KBNODE node )
 	    free_md_filter_context( &c->mfx );
 	    /* prepare to create all requested message digests */
 	    c->mfx.md = md_open(0, 0);
+
 	    /* fixme: why looking for the signature packet and not 1passpacket*/
 	    for( n1 = node; (n1 = find_next_kbnode(n1, PKT_SIGNATURE )); ) {
 		md_enable( c->mfx.md, n1->pkt->pkt.signature->digest_algo);
 	    }
 	    /* ask for file and hash it */
 	    if( c->sigs_only )
-		rc = hash_datafiles( c->mfx.md, c->signed_data, c->sigfilename,
+		rc = hash_datafiles( c->mfx.md, NULL,
+				     c->signed_data, c->sigfilename,
 			n1? (n1->pkt->pkt.onepass_sig->sig_class == 0x01):0 );
 	    else
 		rc = ask_for_detached_datafile( &c->mfx,
@@ -1032,8 +1035,14 @@ proc_tree( CTX c, KBNODE node )
 	if( !c->have_data ) {
 	    free_md_filter_context( &c->mfx );
 	    c->mfx.md = md_open(sig->digest_algo, 0);
+	    if( sig->digest_algo == DIGEST_ALGO_MD5
+		&& is_RSA( sig->pubkey_algo ) ) {
+		/* enable a workaround for a pgp2 bug */
+		c->mfx.md2 = md_open( DIGEST_ALGO_MD5, 0 );
+	    }
 	    if( c->sigs_only )
-		rc = hash_datafiles( c->mfx.md, c->signed_data, c->sigfilename,
+		rc = hash_datafiles( c->mfx.md, c->mfx.md2,
+				     c->signed_data, c->sigfilename,
 				     sig->sig_class == 0x01 );
 	    else
 		rc = ask_for_detached_datafile( &c->mfx,
