@@ -48,7 +48,7 @@ static int  copy_packet( IOBUF inp, IOBUF out, int pkttype,
 					       unsigned long pktlen );
 static void skip_packet( IOBUF inp, int pkttype, unsigned long pktlen );
 static void skip_rest( IOBUF inp, unsigned long pktlen );
-static void *read_rest( IOBUF inp, ulong *r_pktlen );
+static void *read_rest( IOBUF inp, size_t pktlen );
 static int  parse_symkeyenc( IOBUF inp, int pkttype, unsigned long pktlen,
 							     PACKET *packet );
 static int  parse_pubkeyenc( IOBUF inp, int pkttype, unsigned long pktlen,
@@ -71,7 +71,6 @@ static int  parse_compressed( IOBUF inp, int pkttype, unsigned long pktlen,
 static int  parse_encrypted( IOBUF inp, int pkttype, unsigned long pktlen,
 					       PACKET *packet, int new_ctb);
 
-
 static unsigned short
 read_16(IOBUF inp)
 {
@@ -432,6 +431,7 @@ parse( IOBUF inp, PACKET *pkt, int reqtype, ulong *retpos,
 	rc = parse_compressed(inp, pkttype, pktlen, pkt, new_ctb );
 	break;
       case PKT_ENCRYPTED:
+      case PKT_ENCRYPTED_MDC:
 	rc = parse_encrypted(inp, pkttype, pktlen, pkt, new_ctb );
 	break;
       default:
@@ -535,30 +535,9 @@ skip_rest( IOBUF inp, unsigned long pktlen )
     }
 }
 
-static void *
-read_rest( IOBUF inp, ulong *r_pktlen )
-{
-    byte *p;
-    int i;
-    size_t pktlen = *r_pktlen;
-
-    if( iobuf_in_block_mode(inp) ) {
-	log_error("read_rest: can't store stream data\n");
-	p = NULL;
-    }
-    else {
-	p = m_alloc( pktlen + 2 );
-	p[0] = pktlen >> 8;
-	p[1] = pktlen & 0xff;
-	for(i=2; pktlen; pktlen--, i++ )
-	    p[i] = iobuf_get(inp);
-    }
-    *r_pktlen = 0;
-    return p;
-}
 
 static void *
-read_rest2( IOBUF inp, size_t pktlen )
+read_rest( IOBUF inp, size_t pktlen )
 {
     byte *p;
     int i;
@@ -873,6 +852,7 @@ parse_sig_subpkt( const byte *buffer, sigsubpkttype_t reqtype, size_t *ret_n )
 	    if( buflen < 2 )
 		goto too_short;
 	    n = (( n - 192 ) << 8) + *buffer + 192;
+	    buffer++;
 	    buflen--;
 	}
 	if( buflen < n )
@@ -987,7 +967,7 @@ parse_signature( IOBUF inp, int pkttype, unsigned long pktlen,
 	}
 	if( n ) {
 	    sig->hashed_data = m_alloc( n + 2 );
-	    sig->hashed_data[0] = n << 8;
+	    sig->hashed_data[0] = n >> 8;
 	    sig->hashed_data[1] = n;
 	    if( iobuf_read(inp, sig->hashed_data+2, n ) != n ) {
 		log_error("premature eof while reading hashed signature data\n");
@@ -1004,7 +984,7 @@ parse_signature( IOBUF inp, int pkttype, unsigned long pktlen,
 	}
 	if( n ) {
 	    sig->unhashed_data = m_alloc( n + 2 );
-	    sig->unhashed_data[0] = n << 8;
+	    sig->unhashed_data[0] = n >> 8;
 	    sig->unhashed_data[1] = n;
 	    if( iobuf_read(inp, sig->unhashed_data+2, n ) != n ) {
 		log_error("premature eof while reading unhashed signature data\n");
@@ -1065,41 +1045,29 @@ parse_signature( IOBUF inp, int pkttype, unsigned long pktlen,
 	}
     }
 
-    if( !sig->pubkey_algo ) {
-	n = pktlen;
-	sig->data[0] = mpi_read(inp, &n, 0 );
-	pktlen -=n;
-	if( list_mode ) {
-	    printf("\tMDC data: ");
-	    mpi_print(stdout, sig->data[0], mpi_print_mode );
-	    putchar('\n');
-	}
+    ndata = pubkey_get_nsig(sig->pubkey_algo);
+    if( !ndata ) {
+	if( list_mode )
+	    printf("\tunknown algorithm %d\n", sig->pubkey_algo );
+	unknown_pubkey_warning( sig->pubkey_algo );
+	/* we store the plain material in data[0], so that we are able
+	 * to write it back with build_packet() */
+	sig->data[0] = mpi_set_opaque(NULL, read_rest(inp, pktlen), pktlen );
+	pktlen = 0;
     }
     else {
-	ndata = pubkey_get_nsig(sig->pubkey_algo);
-	if( !ndata ) {
-	    if( list_mode )
-		printf("\tunknown algorithm %d\n", sig->pubkey_algo );
-	    unknown_pubkey_warning( sig->pubkey_algo );
-	    /* we store the plain material in data[0], so that we are able
-	     * to write it back with build_packet() */
-	    sig->data[0] = read_rest(inp, &pktlen );
-	}
-	else {
-	    for( i=0; i < ndata; i++ ) {
-		n = pktlen;
-		sig->data[i] = mpi_read(inp, &n, 0 );
-		pktlen -=n;
-		if( list_mode ) {
-		    printf("\tdata: ");
-		    mpi_print(stdout, sig->data[i], mpi_print_mode );
-		    putchar('\n');
-		}
+	for( i=0; i < ndata; i++ ) {
+	    n = pktlen;
+	    sig->data[i] = mpi_read(inp, &n, 0 );
+	    pktlen -=n;
+	    if( list_mode ) {
+		printf("\tdata: ");
+		mpi_print(stdout, sig->data[i], mpi_print_mode );
+		putchar('\n');
 	    }
 	}
     }
 
-
   leave:
     skip_rest(inp, pktlen);
     return rc;
@@ -1243,7 +1211,9 @@ parse_key( IOBUF inp, int pkttype, unsigned long pktlen,
 	byte temp[8];
 
 	if( !npkey ) {
-	    sk->skey[0] = read_rest( inp, &pktlen );
+	    sk->skey[0] = mpi_set_opaque( NULL,
+					  read_rest(inp, pktlen), pktlen );
+	    pktlen = 0;
 	    goto leave;
 	}
 
@@ -1361,7 +1331,7 @@ parse_key( IOBUF inp, int pkttype, unsigned long pktlen,
 	     * stuff up to the end of the packet into the first
 	     * skey element */
 	    sk->skey[npkey] = mpi_set_opaque(NULL,
-					     read_rest2(inp, pktlen), pktlen );
+					     read_rest(inp, pktlen), pktlen );
 	    pktlen = 0;
 	    if( list_mode ) {
 		printf("\tencrypted stuff follows\n");
@@ -1393,7 +1363,9 @@ parse_key( IOBUF inp, int pkttype, unsigned long pktlen,
 	PKT_public_key *pk = pkt->pkt.public_key;
 
 	if( !npkey ) {
-	    pk->pkey[0] = read_rest( inp, &pktlen );
+	    pk->pkey[0] = mpi_set_opaque( NULL,
+					  read_rest(inp, pktlen), pktlen );
+	    pktlen = 0;
 	    goto leave;
 	}
 
@@ -1565,6 +1537,25 @@ parse_encrypted( IOBUF inp, int pkttype, unsigned long pktlen,
     ed->len = pktlen;
     ed->buf = NULL;
     ed->new_ctb = new_ctb;
+    ed->mdc_method = 0;
+    if( pkttype == PKT_ENCRYPTED_MDC ) {
+	/* test: this is the new encrypted_mdc packet */
+	/* fixme: add some pktlen sanity checks */
+	int version, method;
+
+	version = iobuf_get_noeof(inp); pktlen--;
+	if( version != 1 ) {
+	    log_error("encrypted_mdc packet with unknown version %d\n",
+								version);
+	    goto leave;
+	}
+	method = iobuf_get_noeof(inp); pktlen--;
+	if( method != DIGEST_ALGO_SHA1 ) {
+	    log_error("encrypted_mdc does not use SHA1 method\n" );
+	    goto leave;
+	}
+	ed->mdc_method = method;
+    }
     if( pktlen && pktlen < 10 ) { /* actually this is blocksize+2 */
 	log_error("packet(%d) too short\n", pkttype);
 	skip_rest(inp, pktlen);
@@ -1575,6 +1566,8 @@ parse_encrypted( IOBUF inp, int pkttype, unsigned long pktlen,
 	    printf(":encrypted data packet:\n\tlength: %lu\n", pktlen);
 	else
 	    printf(":encrypted data packet:\n\tlength: unknown\n");
+	if( ed->mdc_method )
+	    printf("\tmdc_method: %d\n", ed->mdc_method );
     }
 
     ed->buf = inp;
@@ -1584,5 +1577,3 @@ parse_encrypted( IOBUF inp, int pkttype, unsigned long pktlen,
     return 0;
 }
 
-
-
