@@ -133,14 +133,20 @@ passphrase_to_dek( u32 *keyid, int cipher_algo, STRING2KEY *s2k, int mode )
 					    :DEFAULT_DIGEST_ALGO;
     }
 
-    if( keyid && !next_pw && is_status_enabled() ) {
+    if( !next_pw && is_status_enabled() ) {
 	char buf[50];
-	sprintf( buf, "%08lX%08lX", (ulong)keyid[0], (ulong)keyid[1] );
-	if( keyid[2] && keyid[3] && keyid[0] != keyid[2]
-				 && keyid[1] != keyid[3] )
-	    sprintf( buf+strlen(buf), " %08lX%08lX",
-				      (ulong)keyid[2], (ulong)keyid[3] );
-	write_status_text( STATUS_NEED_PASSPHRASE, buf );
+	if( keyid ) {
+	    sprintf( buf, "%08lX%08lX", (ulong)keyid[0], (ulong)keyid[1] );
+	    if( keyid[2] && keyid[3] && keyid[0] != keyid[2]
+				     && keyid[1] != keyid[3] )
+		sprintf( buf+strlen(buf), " %08lX%08lX",
+					  (ulong)keyid[2], (ulong)keyid[3] );
+	    write_status_text( STATUS_NEED_PASSPHRASE, buf );
+	}
+	else {
+	    sprintf( buf, "%d %d %d", cipher_algo, s2k->mode, s2k->hash_algo );
+	    write_status_text( STATUS_NEED_PASSPHRASE_SYM, buf );
+	}
     }
 
     if( keyid && !opt.batch && !next_pw ) {
@@ -195,6 +201,10 @@ passphrase_to_dek( u32 *keyid, int cipher_algo, STRING2KEY *s2k, int mode )
 	    m_free(pw2);
 	}
     }
+
+    if( !pw || !*pw )
+	write_status( STATUS_MISSING_PASSPHRASE );
+
     dek = m_alloc_secure( sizeof *dek );
     dek->algo = cipher_algo;
     if( !*pw && mode == 2 )
