@@ -64,7 +64,7 @@ signature_check( PKT_signature *sig, MD_HANDLE digest )
 
     free_public_key( pk );
 
-    if( !rc && is_status_enabled() ) {
+    if( !rc && sig->sig_class < 2 && is_status_enabled() ) {
 	/* This signature id works best with DLP algorithms because
 	 * they use a random parameter for every signature.  Instead of
 	 * this sig-id we could have also used the hash of the document
@@ -95,8 +95,9 @@ signature_check( PKT_signature *sig, MD_HANDLE digest )
 	}
 	md_final( md );
 	p = make_radix64_string( md_read( md, 0 ), 20 );
-	buffer = m_alloc( strlen(p) + 40 );
-	sprintf( buffer, "%s %s", p, strtimestamp( sig->timestamp ) );
+	buffer = m_alloc( strlen(p) + 60 );
+	sprintf( buffer, "%s %s %lu",
+		 p, strtimestamp( sig->timestamp ), (ulong)sig->timestamp );
 	write_status_text( STATUS_SIG_ID, buffer );
 	m_free(buffer);
 	m_free(p);
@@ -107,7 +108,7 @@ signature_check( PKT_signature *sig, MD_HANDLE digest )
 }
 
 
-
+#if 0 /* not anymore used */
 /****************
  * Check the MDC which is contained in SIG.
  * The MD_HANDLE should be currently open, so that this function
@@ -193,7 +194,7 @@ mdc_kludge_check( PKT_signature *sig, MD_HANDLE digest )
 
     return rc;
 }
-
+#endif
 
 /****************
  * This function gets called by pubkey_verify() if the algorithm needs it.
