@@ -55,6 +55,14 @@
 #define STATUS_BAD_PASSPHRASE  25
 #define STATUS_NO_PUBKEY       26
 #define STATUS_NO_SECKEY       27
+#define STATUS_NEED_PASSPHRASE_SYM 28
+#define STATUS_DECRYPTION_FAILED 29
+#define STATUS_DECRYPTION_OKAY	 30
+#define STATUS_MISSING_PASSPHRASE 31
+#define STATUS_GOOD_PASSPHRASE	32
+#define STATUS_GOODMDC		33
+#define STATUS_BADMDC		34
+#define STATUS_ERRMDC		35
 
 /*-- status.c --*/
 void set_status_fd ( int fd );
