@@ -47,6 +47,7 @@ static ushort koi82unicode[128] = {
     0x042c,0x042b,0x0417,0x0428,0x042d,0x0429,0x0427,0x042a
 };
 
+#if 0
 static ushort latin2_unicode[128] = {
     0x0080,0x0081,0x0082,0x0083,0x0084,0x0085,0x0086,0x0087,
     0x0088,0x0089,0x008A,0x008B,0x008C,0x008D,0x008E,0x008F,
@@ -65,7 +66,7 @@ static ushort latin2_unicode[128] = {
     0x0111,0x0144,0x0148,0x00F3,0x00F4,0x0151,0x00F6,0x00F7,
     0x0159,0x016F,0x00FA,0x0171,0x00FC,0x00FD,0x0163,0x02D9
 };
-
+#endif
 
 
 void
@@ -213,17 +214,14 @@ trim_spaces( char *str )
 
 
 
-/****************
- * remove trailing white spaces and return the length of the buffer
- */
 unsigned
-trim_trailing_ws( byte *line, unsigned len )
+trim_trailing_chars( byte *line, unsigned len, const char *trimchars )
 {
     byte *p, *mark;
     unsigned n;
 
     for(mark=NULL, p=line, n=0; n < len; n++, p++ ) {
-	if( strchr(" \t\r\n", *p ) ) {
+	if( strchr(trimchars, *p ) ) {
 	    if( !mark )
 		mark = p;
 	}
@@ -238,6 +236,15 @@ trim_trailing_ws( byte *line, unsigned len )
     return len;
 }
 
+/****************
+ * remove trailing white spaces and return the length of the buffer
+ */
+unsigned
+trim_trailing_ws( byte *line, unsigned len )
+{
+    return trim_trailing_chars( line, len, " \t\r\n" );
+}
+
 
 
 int
